==> jc-1.4.0.tar.gz: java/awt/datatransfer/MimeTypeParseException.h <==
// public class java.awt.datatransfer.MimeTypeParseException

// class file dependencies
// @dep_class dedc5f6d0708a356 java_awt_datatransfer_MimeTypeParseException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_datatransfer_MimeTypeParseException_H_
#define _JC_java_awt_datatransfer_MimeTypeParseException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$sub_refs	_jc_java_awt_datatransfer_MimeTypeParseException$sub_refs;
typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$sub_nonrefs	_jc_java_awt_datatransfer_MimeTypeParseException$sub_nonrefs;
typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$refs	_jc_java_awt_datatransfer_MimeTypeParseException$refs;
typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$nonrefs	_jc_java_awt_datatransfer_MimeTypeParseException$nonrefs;
typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$object	_jc_java_awt_datatransfer_MimeTypeParseException$object;

typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$fields_struct	_jc_java_awt_datatransfer_MimeTypeParseException$fields_struct;
typedef const struct _jc_java_awt_datatransfer_MimeTypeParseException$vmethods	_jc_java_awt_datatransfer_MimeTypeParseException$vmethods;
typedef const struct _jc_java_awt_datatransfer_MimeTypeParseException$vtable	_jc_java_awt_datatransfer_MimeTypeParseException$vtable;
typedef const struct _jc_java_awt_datatransfer_MimeTypeParseException$vtype	_jc_java_awt_datatransfer_MimeTypeParseException$vtype;

// Class fields structure
struct _jc_java_awt_datatransfer_MimeTypeParseException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_datatransfer_MimeTypeParseException$fields_struct _jc_java_awt_datatransfer_MimeTypeParseException$class_fields;

// Constructors
extern void _jc_java_awt_datatransfer_MimeTypeParseException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_datatransfer_MimeTypeParseException$object *);
extern void _jc_java_awt_datatransfer_MimeTypeParseException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_datatransfer_MimeTypeParseException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_awt_datatransfer_MimeTypeParseException$vmethods {
};

// Vtable
struct _jc_java_awt_datatransfer_MimeTypeParseException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_datatransfer_MimeTypeParseException$vmethods	java_awt_datatransfer_MimeTypeParseException;
};

// Vtype
struct _jc_java_awt_datatransfer_MimeTypeParseException$vtype {
	_jc_type			type;
	_jc_java_awt_datatransfer_MimeTypeParseException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_datatransfer_MimeTypeParseException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_datatransfer_MimeTypeParseException$refs {
    _jc_java_awt_datatransfer_MimeTypeParseException$sub_refs	java_awt_datatransfer_MimeTypeParseException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_datatransfer_MimeTypeParseException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_datatransfer_MimeTypeParseException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_datatransfer_MimeTypeParseException$sub_nonrefs	java_awt_datatransfer_MimeTypeParseException;
};

// Object instance structure
struct _jc_java_awt_datatransfer_MimeTypeParseException$object {
	_jc_java_awt_datatransfer_MimeTypeParseException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_datatransfer_MimeTypeParseException$vtype	*vtype;
	_jc_java_awt_datatransfer_MimeTypeParseException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_datatransfer_MimeTypeParseException$vtype _jc_java_awt_datatransfer_MimeTypeParseException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_datatransfer_MimeTypeParseException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_datatransfer_MimeTypeParseException$class_object;

#endif	/* _JC_java_awt_datatransfer_MimeTypeParseException_H_ */

==> jc-1.4.6.tar.gz: java/awt/datatransfer/MimeTypeParseException.h <==
// public class java.awt.datatransfer.MimeTypeParseException

// class file dependencies
// @dep_class dedc5f6d0708a356 java_awt_datatransfer_MimeTypeParseException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_datatransfer_MimeTypeParseException_H_
#define _JC_java_awt_datatransfer_MimeTypeParseException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$sub_refs	_jc_java_awt_datatransfer_MimeTypeParseException$sub_refs;
typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$sub_nonrefs	_jc_java_awt_datatransfer_MimeTypeParseException$sub_nonrefs;
typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$refs	_jc_java_awt_datatransfer_MimeTypeParseException$refs;
typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$nonrefs	_jc_java_awt_datatransfer_MimeTypeParseException$nonrefs;
typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$object	_jc_java_awt_datatransfer_MimeTypeParseException$object;

typedef struct _jc_java_awt_datatransfer_MimeTypeParseException$fields_struct	_jc_java_awt_datatransfer_MimeTypeParseException$fields_struct;
typedef const struct _jc_java_awt_datatransfer_MimeTypeParseException$vmethods	_jc_java_awt_datatransfer_MimeTypeParseException$vmethods;
typedef const struct _jc_java_awt_datatransfer_MimeTypeParseException$vtable	_jc_java_awt_datatransfer_MimeTypeParseException$vtable;
typedef const struct _jc_java_awt_datatransfer_MimeTypeParseException$vtype	_jc_java_awt_datatransfer_MimeTypeParseException$vtype;

// Class fields structure
struct _jc_java_awt_datatransfer_MimeTypeParseException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_datatransfer_MimeTypeParseException$fields_struct _jc_java_awt_datatransfer_MimeTypeParseException$class_fields;

// Constructors
extern void _jc_java_awt_datatransfer_MimeTypeParseException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_datatransfer_MimeTypeParseException$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_datatransfer_MimeTypeParseException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_datatransfer_MimeTypeParseException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_datatransfer_MimeTypeParseException$vmethods {
};

// Vtable
struct _jc_java_awt_datatransfer_MimeTypeParseException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_datatransfer_MimeTypeParseException$vmethods	java_awt_datatransfer_MimeTypeParseException;
};

// Vtype
struct _jc_java_awt_datatransfer_MimeTypeParseException$vtype {
	_jc_type			type;
	_jc_java_awt_datatransfer_MimeTypeParseException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_datatransfer_MimeTypeParseException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_datatransfer_MimeTypeParseException$refs {
    _jc_java_awt_datatransfer_MimeTypeParseException$sub_refs	java_awt_datatransfer_MimeTypeParseException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_datatransfer_MimeTypeParseException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_datatransfer_MimeTypeParseException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_datatransfer_MimeTypeParseException$sub_nonrefs	java_awt_datatransfer_MimeTypeParseException;
};

// Object instance structure
struct _jc_java_awt_datatransfer_MimeTypeParseException$object {
	_jc_java_awt_datatransfer_MimeTypeParseException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_datatransfer_MimeTypeParseException$vtype	*vtype;
	_jc_java_awt_datatransfer_MimeTypeParseException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_datatransfer_MimeTypeParseException$vtype _jc_java_awt_datatransfer_MimeTypeParseException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_datatransfer_MimeTypeParseException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_datatransfer_MimeTypeParseException$class_object;

#endif	/* _JC_java_awt_datatransfer_MimeTypeParseException_H_ */
